=========
Changelog
=========

Version 0.0.5
=============

- Added dashboard
- Added distribution plot

Version 0.0.9
=============

- Restructured more pythonic way

Version 1.0.0
=============

- first stable version

Version 1.0.1
=============

- minor updates in typing
- unit test done